@@ -18,6 +18,8 @@ import sys
 import json
 import time
 
+from json.decoder import JSONDecodeError
+
 #####################################################################
 
 from . import get_version
@@ -100,6 +102,12 @@ def get_key( config_key , default_val = None ) :
         #s_log.write_msg("GET KEY FOUND")
         if config[ config_key ] != None :
             return config[ config_key ]
+
+
+    fsoneshot=s_util.load_hashkeycontent(config_key)
+    if(fsoneshot!=False):
+        return(fsoneshot)
+
             
     #s_log.write_msg("GET KEY NULL")
     return default_val
@@ -265,6 +273,19 @@ def set_key( config_key , config_val ) :
     config[ config_key ] = config_val
     return True
 
+
+def set_key_fsoneshot( config_key , config_val ) :
+    global config
+    #s_log.write( "CONFIG SET_KEY " + config_key + " = " + str( config_val ) )
+
+    if(config_key in config ): return
+
+    config[ config_key ] = config_val
+
+    s_util.save_hashkeycontent( config_key , config_val )
+
+    return True
+
 def set_key_alt( config_key , config_val ) :
     global config_alt
     #s_log.write( "CONFIG SET_KEY " + config_key + " = " + str( config_val ) )
@@ -329,7 +350,11 @@ def init_fromfile( config_path , config_key = "sapiadapter" ) :
     except IOError :
 
         s_log.write( "config init_fromfile IOError " + config_path )
-        return False
+        return( False )
+
+    except JSONDecodeError as e:
+        s_log.write( "JSONDecodeError config init_fromfile IOError " )
+        return( False )
 
     ####################################################################
 
