@@ -32,6 +32,9 @@ def setup( ) :
 
 #####################################################################
 
+def reset( ) :
+    filepath_delete( )
+    
 def fsize( ) :
     fp = filepath_get( )
 
