@@ -122,6 +122,12 @@ def job_request( params = { } ) :
 
     #####################################################################
 
+    if s_db.fsize_limited( ) :
+        s_log.write( "ERROR fsize_limited" )
+        return( False )
+
+    #####################################################################
+
     payload = s_db.blob_get( )
 
     #####################################################################
@@ -156,7 +162,7 @@ def job_request( params = { } ) :
 
     #####################################################################
 
-    # s_log.write(str(res.headers))
+    #s_log.write(str(res.headers))
 
     jid = res.headers[ "X-Omni-Jid" ]
 
@@ -371,6 +377,11 @@ def get_request_response( request_headers = { }  , payload = "" ) :
 
     ################################################################ 
 
+    token_session=s_config.get_key("token_session")
+    if(token_session!=None):
+        # FIXME TODO why strip?
+        request_headers[ "X-Omni-TokenSession" ] = token_session.strip()
+
     request_headers[ "X-Omni-Traceid" ] = s_log.get_traceid( )   
 
     ################################################################ 
@@ -438,6 +449,11 @@ def get_request_response( request_headers = { }  , payload = "" ) :
     #####################################################################
 
     if ( response.status_code == 200 ) :
+        #X-Sapi-Tokensession
+        if( "X-Sapi-Tokensession" in response.headers ) :
+            token_session=response.headers["X-Sapi-Tokensession"]
+            s_config.set_key_fsoneshot("token_session",token_session)
+            s_log.write(token_session)
         return( response )
 
     #####################################################################
