@@ -510,7 +510,7 @@ def datetime_now_db( td = 0 ) :
 
     d = datetime.now( ) + timedelta( seconds = td)
 
-    return( d.strftime('%Y-%m-%dT%H:%M:%S'))
+    return( d.strftime( "%Y-%m-%dT%H:%M:%S" ) )
 
 def datetime_timedelta_db( dbdtstr , td ) :
     d = datetime.strptime( dbdtstr , "%Y-%m-%dT%H:%M:%S" ) + timedelta( seconds = td )
@@ -520,10 +520,23 @@ def datetime_inrange_db( dbdt1 , dbdt2 , td) :
     d1 = datetime.strptime(dbdt1, '%Y-%m-%dT%H:%M:%S')  
     d2 = datetime.strptime(dbdt2, '%Y-%m-%dT%H:%M:%S') 
 
-    dtdiff=d2-d1
-    dtdiff_seconds=int(dtdiff.total_seconds())
+    dtdiff = d2 - d1
+    dtdiff_seconds = int( dtdiff.total_seconds( ) )
     return( dtdiff_seconds <= td )
 
+def datetime_diff( dt1 , dt2 ) :
+        d1 = datetime.strptime( dt1 , "%Y-%m-%dT%H:%M:%S" )  
+        d2 = datetime.strptime( dt2 , "%Y-%m-%dT%H:%M:%S" ) 
+        dtdiff = d1 - d2 
+        dt = int( dtdiff.total_seconds( ) )
+        return( dt )
+
+
+def datetime_diffnow( dt2 ) :
+    dt1 = datetime_now_db( ) 
+    return( datetime_diff( dt1 , dt2 ) )
+
+
 
 def datetime_centerwindow( p , ec , ew ):
     a = datetime_timedelta_db( p[ ec ] , -0.5 * p[ ew ] )
@@ -535,7 +548,7 @@ def datetime_initstartend( p , es , ee , ew ) :
     if( ( not es in p) and ( not ee in p ) ) :
         a = datetime_now_db( -1 * p[ ew ] )
         b = datetime_now_db( )
-        return([a,b])
+        return( [ a , b ] )
     elif( not ee in p) :
         b = datetime_timedelta_db( p[ es ] , p[ ew ] )
         return([p[es],b])
