@@ -63,6 +63,9 @@ def geterror( ) :
 def flush( ) :
     return( s_db.flush( ) )
 
+def reset( ) :
+    return( s_db.reset( ) )
+
 def uptime( ) :
     return( s_util.uptime( ) )
 def uptime_lap( ) :
